Coverage for tasks/__init__.py: 100%

1"""

2 camcops_server/tasks/__init__.py

3

4===============================================================================

5

6 Copyright (C) 2012, University of Cambridge, Department of Psychiatry.

7 Created by Rudolf Cardinal (rnc1001@cam.ac.uk).

8

9 This file is part of CamCOPS.

10

11 CamCOPS is free software: you can redistribute it and/or modify

12 it under the terms of the GNU General Public License as published by

13 the Free Software Foundation, either version 3 of the License, or

14 (at your option) any later version.

15

16 CamCOPS is distributed in the hope that it will be useful,

17 but WITHOUT ANY WARRANTY; without even the implied warranty of

18 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the

19 GNU General Public License for more details.

20

21 You should have received a copy of the GNU General Public License

22 along with CamCOPS. If not, see <https://www.gnu.org/licenses/>.

23

24===============================================================================

25

26"""

27

28 from camcops_server.tasks.ace3 import Ace3, MiniAce

29 from camcops_server.tasks.aims import Aims

30 from camcops_server.tasks.apeq_cpft_perinatal import APEQCPFTPerinatal

31 from camcops_server.tasks.apeqpt import Apeqpt

32 from camcops_server.tasks.aq import Aq

33 from camcops_server.tasks.asdas import Asdas

34 from camcops_server.tasks.audit import Audit, AuditC

35

36 from camcops_server.tasks.badls import Badls

37 from camcops_server.tasks.basdai import Basdai

38 from camcops_server.tasks.bdi import Bdi

39 from camcops_server.tasks.bmi import Bmi

40 from camcops_server.tasks.bprs import Bprs

41 from camcops_server.tasks.bprse import Bprse

42

43 from camcops_server.tasks.cage import Cage

44 from camcops_server.tasks.cape42 import Cape42

45 from camcops_server.tasks.caps import Caps

46 from camcops_server.tasks.cardinal_expdetthreshold import (

47 CardinalExpDetThreshold,

48)

49 from camcops_server.tasks.cardinal_expectationdetection import (

50 CardinalExpectationDetection,

51)

52 from camcops_server.tasks.cbir import CbiR

53 from camcops_server.tasks.ceca import CecaQ3

54 from camcops_server.tasks.cesd import Cesd

55 from camcops_server.tasks.cesdr import Cesdr

56 from camcops_server.tasks.cet import Cet

57 from camcops_server.tasks.cgi_task import Cgi

58 from camcops_server.tasks.cgisch import CgiSch

59 from camcops_server.tasks.chit import Chit

60 from camcops_server.tasks.cia import Cia

61 from camcops_server.tasks.cisr import Cisr

62 from camcops_server.tasks.ciwa import Ciwa

63 from camcops_server.tasks.contactlog import ContactLog

64 from camcops_server.tasks.cope import CopeBrief

65 from camcops_server.tasks.core10 import Core10

66 from camcops_server.tasks.cpft_lps import (

67 CPFTLPSReferral,

68 CPFTLPSResetResponseClock,

69 CPFTLPSDischarge,

70)

71 from camcops_server.tasks.cpft_covid_medical import CpftCovidMedical

72 from camcops_server.tasks.cpft_research_preferences import (

73 CpftResearchPreferences,

74)

75

76# todo: # from camcops_server.tasks.ctqsf import Ctqsf

77

78 from camcops_server.tasks.dad import Dad

79 from camcops_server.tasks.das28 import Das28

80 from camcops_server.tasks.dast import Dast

81 from camcops_server.tasks.deakin_s1_healthreview import DeakinS1HealthReview

82 from camcops_server.tasks.demoquestionnaire import DemoQuestionnaire

83 from camcops_server.tasks.demqol import Demqol

84 from camcops_server.tasks.diagnosis import DiagnosisIcd9CM, DiagnosisIcd10

85 from camcops_server.tasks.distressthermometer import DistressThermometer

86

87 from camcops_server.tasks.edeq import Edeq

88 from camcops_server.tasks.elixhauserci import ElixhauserCI

89 from camcops_server.tasks.empsa import Empsa

90 from camcops_server.tasks.epds import Epds

91 from camcops_server.tasks.eq5d5l import Eq5d5l

92 from camcops_server.tasks.esspri import Esspri

93

94 from camcops_server.tasks.factg import Factg

95 from camcops_server.tasks.fast import Fast

96 from camcops_server.tasks.fft import Fft

97 from camcops_server.tasks.frs import Frs

98

99 from camcops_server.tasks.gad7 import Gad7

100 from camcops_server.tasks.gaf import Gaf

101 from camcops_server.tasks.gbo import Gbogres, Gbogpc

102 from camcops_server.tasks.gds import Gds15

103 from camcops_server.tasks.gmcpq import GMCPQ

104

105 from camcops_server.tasks.hads import Hads

106 from camcops_server.tasks.hama import Hama

107 from camcops_server.tasks.hamd import Hamd

108 from camcops_server.tasks.hamd7 import Hamd7

109 from camcops_server.tasks.honos import Honos, Honos65, Honosca

110

111 from camcops_server.tasks.icd10depressive import Icd10Depressive

112 from camcops_server.tasks.icd10manic import Icd10Manic

113 from camcops_server.tasks.icd10mixed import Icd10Mixed

114 from camcops_server.tasks.icd10schizophrenia import Icd10Schizophrenia

115 from camcops_server.tasks.icd10schizotypal import Icd10Schizotypal

116 from camcops_server.tasks.icd10specpd import Icd10SpecPD

117 from camcops_server.tasks.ided3d import IDED3D

118 from camcops_server.tasks.iesr import Iesr

119 from camcops_server.tasks.ifs import Ifs

120 from camcops_server.tasks.irac import Irac

121 from camcops_server.tasks.isaaq10 import Isaaq10

122 from camcops_server.tasks.isaaqed import IsaaqEd

123

124 from camcops_server.tasks.khandaker_insight_medical import (

125 KhandakerInsightMedical,

126)

127 from camcops_server.tasks.khandaker_mojo_medical import KhandakerMojoMedical

128 from camcops_server.tasks.khandaker_mojo_medicationtherapy import (

129 KhandakerMojoMedicationTherapy,

130)

131 from camcops_server.tasks.kirby_mcq import Kirby

132 from camcops_server.tasks.khandaker_mojo_sociodemographics import (

133 KhandakerMojoSociodemographics,

134)

135

136 from camcops_server.tasks.lynall_iam_medical import LynallIamMedicalHistory

137 from camcops_server.tasks.lynall_iam_life import LynallIamLifeEvents

138

139 from camcops_server.tasks.maas import Maas

140 from camcops_server.tasks.mast import Mast

141 from camcops_server.tasks.mds_updrs import MdsUpdrs

142 from camcops_server.tasks.mfi20 import Mfi20

143 from camcops_server.tasks.moca import Moca

144

145 from camcops_server.tasks.nart import Nart

146 from camcops_server.tasks.npiq import NpiQ

147

148 from camcops_server.tasks.ors import Ors

149

150 from camcops_server.tasks.panss import Panss

151 from camcops_server.tasks.paradise24 import Paradise24

152 from camcops_server.tasks.pbq import Pbq

153 from camcops_server.tasks.pcl5 import Pcl5

154 from camcops_server.tasks.pcl import PclC, PclM, PclS

155 from camcops_server.tasks.pdss import Pdss

156 from camcops_server.tasks.perinatalpoem import PerinatalPoem

157 from camcops_server.tasks.photo import Photo, PhotoSequence

158 from camcops_server.tasks.phq8 import Phq8

159 from camcops_server.tasks.phq9 import Phq9

160 from camcops_server.tasks.phq15 import Phq15

161 from camcops_server.tasks.progressnote import ProgressNote

162 from camcops_server.tasks.pswq import Pswq

163 from camcops_server.tasks.psychiatricclerking import PsychiatricClerking

164

165 from camcops_server.tasks.qolbasic import QolBasic

166 from camcops_server.tasks.qolsg import QolSG

167

168 from camcops_server.tasks.rand36 import Rand36

169 from camcops_server.tasks.rapid3 import Rapid3

170

171 from camcops_server.tasks.service_satisfaction import (

172 PatientSatisfaction,

173 ReferrerSatisfactionGen,

174 ReferrerSatisfactionSpec,

175)

176 from camcops_server.tasks.sfmpq2 import Sfmpq2

177 from camcops_server.tasks.shaps import Shaps

178 from camcops_server.tasks.slums import Slums

179 from camcops_server.tasks.smast import Smast

180 from camcops_server.tasks.srs import Srs

181 from camcops_server.tasks.suppsp import Suppsp

182

183 from camcops_server.tasks.wemwbs import Swemwbs, Wemwbs

184 from camcops_server.tasks.wsas import Wsas

185

186 from camcops_server.tasks.ybocs import Ybocs, YbocsSc

187

188 from camcops_server.tasks.zbi import Zbi12